# Planck

[![pypi](https://img.shields.io/pypi/v/laktory.svg)](https://pypi.org/project/planck/)
[![test](https://github.com/okube-ai/planck/actions/workflows/test.yml/badge.svg)](https://github.com/okube-ai/planck/actions/workflows/test.yml)
[![downloads](https://static.pepy.tech/badge/planck/month)](https://pepy.tech/project/planck)
[![versions](https://img.shields.io/pypi/pyversions/planck.svg)](https://github.com/okube-ai/planck)
[![license](https://img.shields.io/github/license/okube-ai/planck.svg)](https://github.com/okube-ai/planck/blob/main/LICENSE)

Physical constants and unit conversion.

<img src="docs/images/planck_so.png" alt="settus logo" width="85"/>


Planck makes it easy to convert units and to access physical constant values in multiple units.

## Help
See [documentation](https://www.okube.ai/planck) for more details.


## Installation
Install using 
```commandline
pip install planck
```

For more installation options,
see the [Install](https://www.okube.ai/planck/) section in the documentation.

## A Basic Example

```py
from planck import units

print(1 * units["m"]["ft"])
#> 3.280839895013124
```

To get started with more examples, jump into the [Quickstart](https://www.okube.ai/planck/quickstart/).

## Okube Company
<img src="docs/images/okube.png" alt="okube logo" width="85"/>

[Okube](https://www.okube.ai) is dedicated to building open source frameworks, known as the *kubes*, empowering businesses to build, deploy and operate highly scalable data platforms and AI models. 

